@@ -252,7 +252,7 @@ class PlaylistCreationFlow(discord.ui.View):
             self.author and (interaction.user.id != self.author.id)
         ):
             await interaction.response.send_message(
-                content=_("You are not authorized to interact with this."), ephemeral=True
+                content=_("You are not authorized to interact with this"), ephemeral=True
             )
             return False
         return True
@@ -467,7 +467,7 @@ class PlaylistManageFlow(discord.ui.View):
             self.author and (interaction.user.id != self.author.id)
         ):
             await interaction.response.send_message(
-                content=_("You are not authorized to interact with this."), ephemeral=True
+                content=_("You are not authorized to interact with this"), ephemeral=True
             )
             return False
         return True
