@@ -32,7 +32,7 @@ class PreformattedSource(menus.ListPageSource):
         return page
 
     def get_max_pages(self):
-        """:class:`int`: The maximum number of pages required to paginate this sequence."""
+        """:class:`int`: The maximum number of pages required to paginate this sequence"""
         return self._max_pages or 1
 
 
@@ -57,7 +57,7 @@ class ListSource(menus.ListPageSource):
         return embed
 
     def get_max_pages(self):
-        """:class:`int`: The maximum number of pages required to paginate this sequence."""
+        """:class:`int`: The maximum number of pages required to paginate this sequence"""
         return self._max_pages or 1
 
 
@@ -80,7 +80,7 @@ class EntryPickerSource(menus.ListPageSource):
         idx_start, page_num = self.get_starting_index_and_page_number(menu)
         page = await self.cog.lavalink.construct_embed(messageable=menu.ctx, title=self.message_str)
         page.set_footer(
-            text=_("Page {page_num}/{total_pages} | {num} {entries}.").format(
+            text=_("Page {page_num}/{total_pages} | {num} {entries}").format(
                 page_num=humanize_number(page_num + 1),
                 total_pages=humanize_number(self.get_max_pages()),
                 num=len(self.entries),
@@ -102,5 +102,5 @@ class EntryPickerSource(menus.ListPageSource):
         return self.entries[base : base + self.per_page]  # noqa: E203
 
     def get_max_pages(self):
-        """:class:`int`: The maximum number of pages required to paginate this sequence."""
+        """:class:`int`: The maximum number of pages required to paginate this sequence"""
         return self._max_pages or 1
